@@ -14,8 +14,7 @@
 # License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License
-# along with this library; if not, write to the Free Software Foundation,
-# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# along with this library.  If not, see <https://www.gnu.org/licenses/>.
 #
 
 """A library for reading whole-slide images.
@@ -26,9 +25,10 @@ This package provides Python bindings for the OpenSlide library.
 from __future__ import annotations
 
 from abc import ABCMeta, abstractmethod
+from collections.abc import Iterator, Mapping
 from io import BytesIO
 from types import TracebackType
-from typing import Iterator, Literal, Mapping, TypeVar
+from typing import Literal, TypeVar
 
 from PIL import Image, ImageCms
 
